# coding=utf-8
from .. import Provider as BaseProvider


class Provider(BaseProvider):
    vat_id_formats = (
        'CZ########',
        'CZ#########',
        'CZ##########',
    )

    def vat_id(self):
        """
        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
        :return: A random Czech VAT ID
        """

        return self.bothify(self.random_element(self.vat_id_formats))
